document.addEventListener("DOMContentLoaded", function () {
    let map = L.map('neogeoquiz-map').setView([20, 0], 2);

    // Add OpenStreetMap tiles
    L.tileLayer('https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png', {
        attribution: '&copy; <a href="https://www.openstreetmap.org/copyright">OpenStreetMap</a> contributors'
    }).addTo(map);

    let countriesGeoJSON = null;
    let currentCountry = null;
    let score = 0;
    let questionCount = 0;
    let countryLayer = null;

    // Fetch GeoJSON data via AJAX
    fetch(neogeoquizData.ajax_url + '?action=get_geojson')
        .then(response => response.json())
        .then(data => {
            if (data.success === false) {
                alert('Error fetching GeoJSON data: ' + data.data);
                return;
            }
            countriesGeoJSON = data;
            askQuestion();
        });

    function askQuestion() {
        if (questionCount >= 10) {
            document.getElementById('neogeoquiz-question').innerText = `Quiz complete! Your score: ${score}/10`;
            return;
        }

        // Select a random country
        let randomIndex = Math.floor(Math.random() * countriesGeoJSON.features.length);
        currentCountry = countriesGeoJSON.features[randomIndex];

        // Remove previous highlighted country
        if (countryLayer) {
            map.removeLayer(countryLayer);
        }

        // Display the country name to the user
        document.getElementById('country-name').innerText = currentCountry.properties.NAME;
        questionCount++;
    }

    // Handle map clicks
    map.on('click', function (e) {
        if (!currentCountry) return;

        let clickedCorrectly = false;
        L.geoJSON(currentCountry, {
            onEachFeature: function (feature, layer) {
                if (layer.getBounds().contains(e.latlng)) {
                    clickedCorrectly = true;
                }
            }
        });

        // Highlight the country with green or red borders based on the user's answer
        countryLayer = L.geoJSON(currentCountry, {
            style: {
                color: clickedCorrectly ? "green" : "red", // Green for correct, Red for wrong
                weight: 5,
                opacity: 0.65
            }
        }).addTo(map);

        if (clickedCorrectly) {
            score++;
            document.getElementById('score').innerText = score;
            showDialog('Correct!', 'success');
        } else {
            showDialog('Wrong!', 'error');
        }

        // Ask the next question
        setTimeout(() => {
            askQuestion();
        }, 2000); // Allow time for the user to see the highlighted country
    });

    // Custom dialog box
    function showDialog(message, type) {
        const dialog = document.createElement('div');
        dialog.className = `custom-dialog ${type}`;
        dialog.innerHTML = `<p>${message}</p>`;
        document.body.appendChild(dialog);

        setTimeout(() => {
            dialog.classList.add('fade-out');
            dialog.addEventListener('transitionend', () => dialog.remove());
        }, 2000); // Show for 2 seconds
    }
});

