<?php
/*
Plugin Name: neogeoquiz
Plugin URI: https://www.geography.biz/neogeoquiz-plugin-for-wordpress/
Description: A WordPress plugin that displays a world map and asks users to locate countries.
Version: 1.0
License: GPLv2 or later
License URI: https://www.gnu.org/licenses/gpl-2.0.html
Text Domain: neogeoquiz
Author: Geography.biz
*/

// Enqueue necessary scripts and styles
function neogeoquiz_enqueue_scripts() {
    // Leaflet.js library and CSS
    wp_enqueue_style('leaflet-css', 'https://unpkg.com/leaflet@1.9.4/dist/leaflet.css');
    wp_enqueue_script('leaflet-js', 'https://unpkg.com/leaflet@1.9.4/dist/leaflet.js', [], null, true);

    // Plugin JavaScript and CSS
    wp_enqueue_script('neogeoquiz-js', plugin_dir_url(__FILE__) . 'js/neogeoquiz.js', ['leaflet-js'], null, true);
    wp_enqueue_style('neogeoquiz-css', plugin_dir_url(__FILE__) . 'css/neogeoquiz.css');

    // Pass AJAX URL to JavaScript
    wp_localize_script('neogeoquiz-js', 'neogeoquizData', [
        'ajax_url' => admin_url('admin-ajax.php')
    ]);
}
add_action('wp_enqueue_scripts', 'neogeoquiz_enqueue_scripts');

// Shortcode to display the quiz
function neogeoquiz_shortcode() {
    $output = '<div id="neogeoquiz-container">
        
        <div id="neogeoquiz-questions">
            <p id="neogeoquiz-question">Click on the location of: <span id="country-name"></span></p>
            <p id="neogeoquiz-score">Score: <span id="score">0</span></p>
        </div>
        <div id="neogeoquiz-map"></div>
        
    </div>';
    return $output;
}
add_shortcode('neogeoquiz', 'neogeoquiz_shortcode');

// AJAX endpoint to get GeoJSON file
function neogeoquiz_get_geojson() {
    $geojson_file = plugin_dir_path(__FILE__) . 'geojson/countries/countryBoundaries.geojson';

    if (file_exists($geojson_file)) {
        $geojson_data = file_get_contents($geojson_file);
        wp_send_json(json_decode($geojson_data));
    } else {
        wp_send_json_error('GeoJSON file not found');
    }
}
add_action('wp_ajax_get_geojson', 'neogeoquiz_get_geojson');
add_action('wp_ajax_nopriv_get_geojson', 'neogeoquiz_get_geojson');